act.plotting.plot.Display
=========================

.. currentmodule:: act.plotting.plot

.. autoclass:: Display

   
   .. automethod:: __init__

   
   .. rubric:: Methods

   .. autosummary::
   
      ~Display.__init__
      ~Display.add_colorbar
      ~Display.add_subplots
      ~Display.assign_to_figure_axis
      ~Display.put_display_in_subplot
   
   

   
   
   